pub struct MachineRegisteredEvent {
pub machine_id: &'static str,
pub registered: bool,
}Expand description
The given machine was registered or unregistered within this VirtualBox installation.
Fields
machine_id: &'static strID of the machine this event relates to.
registered: boolIf true, the machine was registered, otherwise it was unregistered.
Implementations
Sourceimpl MachineRegisteredEvent
impl MachineRegisteredEvent
pub fn new(object: *mut IEvent) -> DetailEvent