pub enum VboxErrorType {
Show 43 variants
ErrorInit,
GetFnError,
NullPointerError,
ReleaseError,
ConvertStringError,
UnsupportedInCurrentApiVersion,
IncorrectVersion {
raw_ver: String,
vbox_sys_ver: String,
vbox_ver: u32,
vbox_api_ver: u32,
build_ver: u32,
},
VectorsLengthMismatch,
VBOX_E_DND_ERROR,
NS_ERROR_UNEXPECTED,
NS_ERROR_FACTORY_REGISTER_AGAIN,
VBOX_E_FILE_ERROR,
VBOX_E_GSTCTL_GUEST_ERROR,
NS_ERROR_NOT_AVAILABLE,
VBOX_E_MAXIMUM_REACHED,
E_ACCESSDENIED,
VBOX_E_PDM_ERROR,
NS_ERROR_NOT_IMPLEMENTED,
NS_NOINTERFACE,
NS_ERROR_NO_AGGREGATION,
VBOX_E_PASSWORD_INCORRECT,
NS_ERROR_BASE,
NS_ERROR_FAILURE,
NS_ERROR_INVALID_POINTER,
NS_ERROR_FACTORY_NOT_LOADED,
VBOX_E_XML_ERROR,
VBOX_E_INVALID_SESSION_STATE,
VBOX_E_OBJECT_IN_USE,
VBOX_E_IPRT_ERROR,
VBOX_E_NOT_SUPPORTED,
NS_ERROR_OUT_OF_MEMORY,
NS_ERROR_ABORT,
NS_ERROR_ILLEGAL_VALUE,
VBOX_E_HOST_ERROR,
VBOX_E_INVALID_OBJECT_STATE,
NS_ERROR_FACTORY_NOT_REGISTERED,
VBOX_E_TIMEOUT,
VBOX_E_VM_ERROR,
VBOX_E_INVALID_VM_STATE,
VBOX_E_OBJECT_NOT_FOUND,
VBOX_E_PLATFORM_ARCH_NOT_SUPPORTED,
VBOX_E_RECORDING_ERROR,
UNKNOWN(u32),
}Variants
ErrorInit
GetFnError
NullPointerError
ReleaseError
ConvertStringError
UnsupportedInCurrentApiVersion
This error occurs when the requested method is not supported by the current API version.
IncorrectVersion
VectorsLengthMismatch
An internal error occurs when vectors have different lengths, which is required for consistent processing.
VBOX_E_DND_ERROR
A drag and drop error has occurred.
NS_ERROR_UNEXPECTED
Returned when an unexpected error occurs
NS_ERROR_FACTORY_REGISTER_AGAIN
Returned when a class cannot be registered, but may be tried again later
VBOX_E_FILE_ERROR
File not accessible or erroneous file contents.
VBOX_E_GSTCTL_GUEST_ERROR
Guest Control reported an error from the guest side.
NS_ERROR_NOT_AVAILABLE
Returned when an operation can’t complete due to an unavailable resource
VBOX_E_MAXIMUM_REACHED
A maximum has been reached.
E_ACCESSDENIED
Modification request refused.
VBOX_E_PDM_ERROR
Pluggable Device Manager error.
NS_ERROR_NOT_IMPLEMENTED
Returned by a not implemented function
NS_NOINTERFACE
Returned when a given interface is not supported.
NS_ERROR_NO_AGGREGATION
Returned when a class doesn’t allow aggregation
VBOX_E_PASSWORD_INCORRECT
A provided password was incorrect.
NS_ERROR_BASE
Returned when an unexpected error occurs
NS_ERROR_FAILURE
Returned when a function fails
NS_ERROR_INVALID_POINTER
Returned when a pointer is invalid
NS_ERROR_FACTORY_NOT_LOADED
Returned when a dynamically loaded factory couldn’t be found
VBOX_E_XML_ERROR
Could not parse the settings file.
VBOX_E_INVALID_SESSION_STATE
Current session state prohibits operation.
VBOX_E_OBJECT_IN_USE
Object being in use prohibits operation.
VBOX_E_IPRT_ERROR
Runtime subsystem error.
VBOX_E_NOT_SUPPORTED
Requested operation is not supported.
NS_ERROR_OUT_OF_MEMORY
Returned when a memory allocation fails
NS_ERROR_ABORT
Returned when a function aborts
NS_ERROR_ILLEGAL_VALUE
Returned when an illegal value is passed
VBOX_E_HOST_ERROR
Host operating system related error
VBOX_E_INVALID_OBJECT_STATE
Current object state prohibits operation.
NS_ERROR_FACTORY_NOT_REGISTERED
Returned when a class is not registered
VBOX_E_TIMEOUT
The operation ran into an explicitly requested timeout.
VBOX_E_VM_ERROR
Virtual machine error occurred attempting the operation.
VBOX_E_INVALID_VM_STATE
Current virtual machine state prevents the operation.
VBOX_E_OBJECT_NOT_FOUND
Object corresponding to the supplied arguments does not exist.
VBOX_E_PLATFORM_ARCH_NOT_SUPPORTED
Platform architecture is not supported.
VBOX_E_RECORDING_ERROR
A recording error has occurred.
UNKNOWN(u32)
Unknown error